@@ -5,6 +5,7 @@
 // http://opensource.org/licenses/MIT>, at your option. This file may not be
 // copied, modified, or distributed except according to those terms.
 
+use pyo3::IntoPyObjectExt;
 use pyo3::class::basic::CompareOp;
 use pyo3::prelude::*;
 
@@ -57,8 +58,8 @@ impl Score {
     fn __richcmp__(&self, other: PyRef<Score>, op: CompareOp) -> Py<PyAny> {
         let py = other.py();
         match op {
-            CompareOp::Eq => (self.inner == other.inner).into_py(py),
-            CompareOp::Ne => (self.inner != other.inner).into_py(py),
+            CompareOp::Eq => (self.inner == other.inner).into_py_any(py).unwrap(),
+            CompareOp::Ne => (self.inner != other.inner).into_py_any(py).unwrap(),
             _ => py.NotImplemented(),
         }
     }
